/**
 * 
 */
package jalview.api;

import java.util.Hashtable;

import jalview.datamodel.AlignmentAnnotation;
import jalview.datamodel.AlignmentI;
import jalview.datamodel.ColumnSelection;
import jalview.schemes.ColourSchemeI;

/**
 * @author jimp
 *
 */
public interface AlignViewportI
{

  int getCharWidth();

  int getEndRes();

  int getCharHeight();

  boolean hasHiddenColumns();

  boolean isValidCharWidth();

  boolean isShowConsensusHistogram();

  boolean isShowSequenceLogo();

  boolean isNormaliseSequenceLogo();

  ColourSchemeI getGlobalColourScheme();

  AlignmentI getAlignment();

  ColumnSelection getColumnSelection();

  Hashtable[] getSequenceConsensusHash();

  Hashtable[] getRnaStructureConsensusHash();

  boolean getIgnoreGapsConsensus();

  boolean getCentreColumnLabels();

  boolean isCalculationInProgress(AlignmentAnnotation alignmentAnnotation);

  AlignmentAnnotation getAlignmentQualityAnnot();

  AlignmentAnnotation getAlignmentConservationAnnotation();
  /**
   * get the container for alignment consensus annotation
   * @return
   */
  AlignmentAnnotation getAlignmentConsensusAnnotation();

  /**
   * Test to see if viewport is still open and active
   * @return true indicates that all references to viewport should be dropped 
   */
  boolean isClosed();
  /**
   * get the associated calculation thread manager for the view
   * @return
   */
  AlignCalcManagerI getCalcManager();
  
  /**
   * get the percentage gaps allowed in a conservation calculation
   * 
   */
  public int getConsPercGaps();

  /**
   * set the consensus result object for the viewport
   * @param hconsensus
   */
  void setSequenceConsensusHash(Hashtable[] hconsensus);

  /**
   * 
   * @return the alignment annotatino row for the structure consensus calculation
   */
  AlignmentAnnotation getAlignmentStrucConsensusAnnotation();

  /**
   * set the Rna structure consensus result object for the viewport
   * @param hStrucConsensus 
   */
  void setRnaStructureConsensusHash(Hashtable[] hStrucConsensus);

}
